'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var getBaseURL = function getBaseURL(url) {
  return url.replace(/[?#].*$/, '');
};
var isAbsoluteURL = function isAbsoluteURL(url) {
  return /^[a-z][a-z0-9+.-]*:/.test(url);
};
var getURLParameters = function getURLParameters(url) {
  return (url.match(/([^?=&]+)(=([^&]*))/g) || []).reduce(function (a, v) {
    return a[v.slice(0, v.indexOf('='))] = v.slice(v.indexOf('=') + 1), a;
  }, {});
};

var containsElement = function containsElement(parent, child) {
  return parent !== child && parent.contains(child);
};
var getAncestors = function getAncestors(el) {
  var ancestors = [];

  while (el) {
    ancestors.unshift(el);
    el = el.parentNode;
  }

  return ancestors;
};
var smoothScroll = function smoothScroll(element) {
  var _document$querySelect;

  return (_document$querySelect = document.querySelector(element)) == null ? void 0 : _document$querySelect.scrollIntoView({
    behavior: 'smooth'
  });
};
var onClickOutside = function onClickOutside(element, callback) {
  document.addEventListener('click', function (e) {
    if (!element.contains(e.target)) callback();
  });
};
var fullscreen = function fullscreen(mode, el) {
  var _document$querySelect2;

  if (mode === void 0) {
    mode = true;
  }

  if (el === void 0) {
    el = 'body';
  }

  return mode ? (_document$querySelect2 = document.querySelector(el)) == null ? void 0 : _document$querySelect2.requestFullscreen() : document.exitFullscreen();
};

var generateUUID = function generateUUID() {
  return (//  @ts-ignore
    ([1e7] + -1e3 + -4e3 + -8e3 + -1e11).replace(/[018]/g, function (c) {
      return (c ^ crypto.getRandomValues(new Uint8Array(1))[0] & 15 >> c / 4).toString(16);
    })
  );
};

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };
  return _setPrototypeOf(o, p);
}

function _isNativeReflectConstruct() {
  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
  if (Reflect.construct.sham) return false;
  if (typeof Proxy === "function") return true;

  try {
    Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
    return true;
  } catch (e) {
    return false;
  }
}

function _construct(Parent, args, Class) {
  if (_isNativeReflectConstruct()) {
    _construct = Reflect.construct.bind();
  } else {
    _construct = function _construct(Parent, args, Class) {
      var a = [null];
      a.push.apply(a, args);
      var Constructor = Function.bind.apply(Parent, a);
      var instance = new Constructor();
      if (Class) _setPrototypeOf(instance, Class.prototype);
      return instance;
    };
  }

  return _construct.apply(null, arguments);
}

//  @ts-ignore
var isDateValid = function isDateValid() {
  for (var _len = arguments.length, val = new Array(_len), _key = 0; _key < _len; _key++) {
    val[_key] = arguments[_key];
  }

  return !Number.isNaN(_construct(Date, val).valueOf());
};
var getUnixTimestamp = function getUnixTimestamp(date) {
  if (date === void 0) {
    date = new Date();
  }

  return Math.floor(date.getTime() / 1000);
};

exports.containsElement = containsElement;
exports.fullscreen = fullscreen;
exports.generateUUID = generateUUID;
exports.getAncestors = getAncestors;
exports.getBaseURL = getBaseURL;
exports.getURLParameters = getURLParameters;
exports.getUnixTimestamp = getUnixTimestamp;
exports.isAbsoluteURL = isAbsoluteURL;
exports.isDateValid = isDateValid;
exports.onClickOutside = onClickOutside;
exports.smoothScroll = smoothScroll;
//# sourceMappingURL=js-ts-utilities.cjs.development.js.map
